@@ -118,60 +118,66 @@ class Interface():
     vrf: str
 
     def __init__(self, **kwargs):
-        from netwalk.switch import Switch
-        self.logger = logging.getLogger(__name__)
-        self.name: str = kwargs.get('name', None)
+        from netwalk.device import Switch
+        self.name: str = kwargs.get('name')
         self.description: Optional[str] = kwargs.get('description', "")
 
-        self.abort: Optional[str] = kwargs.get('abort', None)
+        self.abort: Optional[str] = kwargs.get('abort')
         self.address: dict = kwargs.get('address', {})
-        self.allowed_vlan: set = kwargs.get('allowed_vlan', None)
-        self.bandwidth: Optional[str] = kwargs.get('bandwidth', None)
-        self.bia: Optional[str] = kwargs.get('bia', None)
+        self.allowed_vlan: set = kwargs.get('allowed_vlan')
+        self.bandwidth: Optional[str] = kwargs.get('bandwidth')
+        self.bia: Optional[str] = kwargs.get('bia')
         self.bpduguard: bool = kwargs.get('bpduguard', False)
-        self.channel_group: Optional[int] = kwargs.get('channel_group', None)
-        self.channel_protocol: Optional[str] = kwargs.get('channel_protocol', None)
+        self.channel_group: Optional[int] = kwargs.get('channel_group')
+        self.channel_protocol: Optional[str] = kwargs.get('channel_protocol')
         self.child_interfaces: List[Interface] = kwargs.get('child_interfaces', [])
-        self.config: List[str] = kwargs.get('config', [])
-        self.counters: Optional[dict] = kwargs.get('counters', None)
-        self.crc: Optional[str] = kwargs.get('crc', None)
-        self.delay: Optional[str] = kwargs.get('delay', None)
-        self.duplex: Optional[str] = kwargs.get('duplex', None)
-        self.encapsulation: Optional[str] = kwargs.get('encapsulation', None)
-        self.hardware_type: Optional[str] = kwargs.get('hardware_type', None)
-        self.input_errors: Optional[str] = kwargs.get('input_errors', None)
-        self.input_packets: Optional[str] = kwargs.get('input_packets', None)
-        self.input_rate: Optional[str] = kwargs.get('input_rate', None)
+        self.config: List[str] = kwargs.get('config')
+        self.counters: Optional[dict] = kwargs.get('counters')
+        self.device: Optional[Switch] = kwargs.get('device')
+        self.crc: Optional[str] = kwargs.get('crc')
+        self.delay: Optional[str] = kwargs.get('delay')
+        self.duplex: Optional[str] = kwargs.get('duplex')
+        self.encapsulation: Optional[str] = kwargs.get('encapsulation')
+        self.hardware_type: Optional[str] = kwargs.get('hardware_type')
+        self.input_errors: Optional[str] = kwargs.get('input_errors')
+        self.input_packets: Optional[str] = kwargs.get('input_packets')
+        self.input_rate: Optional[str] = kwargs.get('input_rate')
         self.is_enabled: bool = kwargs.get('is_enabled', True)
         self.is_up: bool = kwargs.get('is_up', True)
-        self.last_clearing: Optional[datetime] = kwargs.get('last_clear', None)
-        self.last_in: Optional[datetime] = kwargs.get('last_in', None)
-        self.last_out_hang: Optional[datetime] = kwargs.get('last_out_hang', None)
-        self.last_out: Optional[datetime] = kwargs.get('last_out', None)
-        self.mac_address: Optional[EUI] = kwargs.get('mac_address', None)
+        self.last_clearing: Optional[datetime] = kwargs.get('last_clear')
+        self.last_in: Optional[datetime] = kwargs.get('last_in')
+        self.last_out_hang: Optional[datetime] = kwargs.get('last_out_hang')
+        self.last_out: Optional[datetime] = kwargs.get('last_out')
+        self.mac_address: Optional[EUI] = kwargs.get('mac_address')
         self.mac_count: int = 0
-        self.media_type: Optional[str] = kwargs.get('media_type', None)
+        self.media_type: Optional[str] = kwargs.get('media_type')
         self.mode: str = kwargs.get('mode', 'access')
-        self.mtu: Optional[int] = kwargs.get('mtu', None)
+        self.mtu: Optional[int] = kwargs.get('mtu')
         self.native_vlan: int = kwargs.get('native_vlan', 1)
         self.neighbors: List[Any[Interface, dict]] = kwargs.get('neighbors', [])
-        self.output_errors: Optional[str] = kwargs.get('output_errors', None)
-        self.output_packets: Optional[str] = kwargs.get('output_packets', None)
-        self.output_rate: Optional[str] = kwargs.get('output_rate', None)
-        self.parent_interface: Optional[Interface] = kwargs.get('parent_interface', None)
-        self.protocol_status: Optional[str] = kwargs.get('protocol_status', None)
-        self.queue_strategy: Optional[str] = kwargs.get('queue_strategy', None)
+        self.output_errors: Optional[str] = kwargs.get('output_errors')
+        self.output_packets: Optional[str] = kwargs.get('output_packets')
+        self.output_rate: Optional[str] = kwargs.get('output_rate')
+        self.parent_interface: Optional[Interface] = kwargs.get('parent_interface')
+        self.protocol_status: Optional[str] = kwargs.get('protocol_status')
+        self.queue_strategy: Optional[str] = kwargs.get('queue_strategy')
         self.routed_port: bool = kwargs.get('routed_port', False)
-        self.sort_order: Optional[int] = kwargs.get('sort_order', None)
-        self.speed: Optional[str] = kwargs.get('speed', None)
-        self.switch: Optional[Switch] = kwargs.get('switch', None)
+        self.sort_order: Optional[int] = kwargs.get('sort_order')
+        self.speed: Optional[str] = kwargs.get('speed')
         self.type_edge: bool = kwargs.get('type_edge', False)
         self.unparsed_lines: List[str] = kwargs.get('unparsed_lines', [])
-        self.voice_vlan: Optional[int] = kwargs.get('voice_vlan', None)
+        self.voice_vlan: Optional[int] = kwargs.get('voice_vlan')
         self.vrf: str = kwargs.get('vrf', "default")
 
+        if self.name is None:
+            self.logger = logging.getLogger(__name__)
+        else:
+            self.logger = logging.getLogger(__name__ + self.name)
+
         if self.config is not None:
             self.parse_config()
+        else:
+            self.config = []
 
         if self.name is not None:
             self._calculate_sort_order()
@@ -184,7 +190,7 @@ class Interface():
 
         if not second_pass:
             # Pass values to unparsed_lines as value not reference
-            self.unparsed_lines = self.config[:]
+            self.unparsed_lines = [x.rstrip() for x in self.config[:]]
 
         # Parse port mode first. Some switches have it first, some last, so check it first thing
         for line in self.unparsed_lines:
@@ -205,6 +211,9 @@ class Interface():
             # Find interface name
             match = re.search(r"^interface ([A-Za-z\-]*(\/*\d*)+\.?\d*)", cleanline)
             if match is not None:
+                if self.name is None:
+                    self.logger = logging.getLogger(__name__ + match.groups()[0])
+
                 self.name = match.groups()[0]
                 if "vlan" in self.name.lower():
                     self.routed_port = True
@@ -225,8 +234,8 @@ class Interface():
             match = re.search(r"channel\-group (\d+) mode (\w+)", cleanline)
             if match is not None:
                 po_id, mode = match.groups()
-                if self.switch is not None:
-                    parent_po = self.switch.interfaces.get(f'Port-channel{str(po_id)}', None)
+                if self.device is not None:
+                    parent_po = self.device.interfaces.get(f'Port-channel{str(po_id)}', None)
                     if parent_po is not None:
                         parent_po.add_child_interface(self)
                         self.unparsed_lines.remove(line)
@@ -303,10 +312,12 @@ class Interface():
                 continue
 
             if "no shutdown" in line:
+                self.logger.debug("Set shutdown = False")
                 self.is_enabled = True
                 self.unparsed_lines.remove(line)
                 continue
             elif "shutdown" in line:
+                self.logger.debug("Set shutdown = True")
                 self.is_enabled = False
                 self.unparsed_lines.remove(line)
                 continue
@@ -422,7 +433,7 @@ class Interface():
             sortid += str(last_port).zfill(3)
             sortid += str(subint).zfill(4)
 
-            self.sort_order = int(sortid)
+            self.sort_order = int(sortid.replace(" ",""))
 
     def _allowed_vlan_to_list(self, vlanlist: str) -> set:
         """
@@ -446,70 +457,89 @@ class Interface():
 
         return out
 
-    def __str__(self) -> str:
+    def generate_config(self, full=False) -> str:
         """Generate show run from self data"""
+        
         if self.name is None:
             raise KeyError("Must define at least a name")
-
+        
         fullconfig = f"interface {self.name}\n"
 
         if self.description != "":
-            fullconfig = fullconfig + f" description {self.description}\n"
+            fullconfig += f" description {self.description}\n"
+        elif full:
+            fullconfig += " no description\n"
         
         if isinstance(self.parent_interface, Interface):
             if "Port-channel" in self.parent_interface.name:
                 fullconfig += f" channel-group {self.channel_group} mode {self.channel_protocol}\n"
 
         if not self.routed_port:
-            fullconfig = fullconfig + f" switchport mode {self.mode}\n"
+            fullconfig += f" switchport mode {self.mode}\n"
 
             if self.mode == "access":
-                fullconfig = fullconfig + f" switchport access vlan {self.native_vlan}\n"
+                if full:
+                    fullconfig += " no switchport trunk native vlan\n no switchport trunk allowed vlan\n"
+
+                fullconfig += f" switchport access vlan {self.native_vlan}\n"
 
             elif self.mode== "trunk":
-                fullconfig = fullconfig + f" switchport trunk native vlan {self.native_vlan}\n"
+                if full:
+                    fullconfig += " no switchport access vlan\n"
+
+                fullconfig += f" switchport trunk native vlan {self.native_vlan}\n"
                 if self.allowed_vlan is None:
                     fullconfig = fullconfig + " switchport trunk allowed vlan all\n"
                 elif len(self.allowed_vlan) != 4094:
                     sorted_allowed_vlan = list(self.allowed_vlan)
                     sorted_allowed_vlan.sort()
                     vlan_str = ",".join(map(str, sorted_allowed_vlan))
-                    fullconfig = fullconfig + f" switchport trunk allowed vlan {vlan_str}\n"
+                    fullconfig += f" switchport trunk allowed vlan {vlan_str}\n"
                 else:
-                    fullconfig = fullconfig + " switchport trunk allowed vlan all\n"
+                    fullconfig += " switchport trunk allowed vlan all\n"
             else:
                 self.logger.warning("Port %s mode %s", self.name, self.mode)
 
 
             if self.mode == "access" and self.voice_vlan is not None:
-                fullconfig = fullconfig + f" switchport voice vlan {self.voice_vlan}\n"
+                fullconfig += f" switchport voice vlan {self.voice_vlan}\n"
+            elif full:
+                fullconfig += " no switchport voice vlan\n"
 
             if self.type_edge:
-                fullconfig = fullconfig + " spanning-tree portfast"
+                fullconfig += " spanning-tree portfast"
 
                 if self.mode == "trunk":
-                    fullconfig = fullconfig + " trunk\n"
+                    fullconfig += " trunk\n"
                 else:
-                    fullconfig = fullconfig + "\n"
+                    fullconfig += "\n"
+            elif full:
+                fullconfig += " no spanning-tree portfast\n"
 
             if self.bpduguard:
                 fullconfig = fullconfig + " spanning-tree bpduguard enable\n"
+            elif full:
+                fullconfig += " no spanning-tree bpduguard\n"
 
         else:
             if self.vrf != 'default':
-                fullconfig = fullconfig + " vrf forwarding " + self.vrf + "\n"
+                fullconfig +=" vrf forwarding " + self.vrf + "\n"
+            elif full:
+                fullconfig += " no vrf forwarding\n"
 
             if 'ipv4' in self.address:
                 for k, v in self.address['ipv4'].items():
-                    fullconfig = fullconfig + f" ip address {k.ip} {k.netmask}"
+                    fullconfig += f" ip address {k.ip} {k.netmask}"
                     if v['type'] == 'secondary':
-                        fullconfig = fullconfig + " secondary\n"
+                        fullconfig += " secondary\n"
                     elif v['type'] == 'primary':
-                        fullconfig = fullconfig + "\n"
+                        fullconfig += "\n"
+            elif full:
+                fullconfig += " no ip address\n"
 
             if 'hsrp' in self.address:
                 if self.address['hsrp']['version'] != 1:
-                    fullconfig = fullconfig + " standby version " + str(self.address['hsrp']['version']) + "\n"
+                    fullconfig += " standby version " + str(self.address['hsrp']['version']) + "\n"
                 for k, v in self.address['hsrp']['groups'].items():
                     line_begin = f" standby {k} " if k != 0 else " standby "
                     fullconfig = fullconfig + line_begin + "ip " + str(v['address']) + "\n"
@@ -530,3 +560,6 @@ class Interface():
 
         fullconfig = fullconfig + "!\n"
         return fullconfig
+
+    def __str__(self) -> str:
+        return self.generate_config()
\ No newline at end of file
